Class: TrailerVote::Api::Place::Children
- Inherits:
-
Object
- Object
- TrailerVote::Api::Place::Children
- Defined in:
- lib/trailer_vote/api/place/children.rb,
lib/trailer_vote/api/place/children/urls.rb
Defined Under Namespace
Classes: Urls
Instance Method Summary collapse
-
#back ⇒ TrailerVote::Api::Product::Find
Api to deal with a found place.
-
#initialize(configuration:, place: nil) ⇒ Children
constructor
A new instance of Children.
-
#urls ⇒ TrailerVote::Api::Place::Children::Urls
The api to get the children urls for the current place.
Constructor Details
#initialize(configuration:, place: nil) ⇒ Children
Returns a new instance of Children.
17 18 19 20 |
# File 'lib/trailer_vote/api/place/children.rb', line 17 def initialize(configuration:, place: nil) self.configuration = configuration self.place = place end |
Instance Method Details
#back ⇒ TrailerVote::Api::Product::Find
Returns api to deal with a found place.
23 24 25 |
# File 'lib/trailer_vote/api/place/children.rb', line 23 def back place end |
#urls ⇒ TrailerVote::Api::Place::Children::Urls
Returns the api to get the children urls for the current place.
12 13 14 |
# File 'lib/trailer_vote/api/place/children/urls.rb', line 12 def urls Urls.new(configuration: configuration, place: place) end |